pub struct Connection { /* private fields */ }Expand description
Connection details for script clients.
Defines the credentials, hostname, and database to connect to.
Implementations
Sourceimpl Connection
impl Connection
Sourcepub fn new(
hostname: impl Into<String>,
database: impl Into<String>,
username: impl Into<String>,
password: impl Into<String>,
) -> Connection
pub fn new( hostname: impl Into<String>, database: impl Into<String>, username: impl Into<String>, password: impl Into<String>, ) -> Connection
Creates a new connection.
Will use the HTTPS by default, unless changes.
Examples
use fm_script_client::Connection;
let connection = Connection::new("example.com", "test_sb", "foo", "bar");Sourcepub fn without_tls(self, disable_tls: bool) -> Self
pub fn without_tls(self, disable_tls: bool) -> Self
Disables TLS which forces the client to fall back to HTTP.